package com.reyun.bpu.dmp.utils;

import java.io.Serializable;

public class Result<T> implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 响应代码
	 */
	private String code;

	/**
	 * 返回说明
	 */
	private String msg;

	/**
	 * 返回结果
	 */
	private T data;

	public Result() {

	}

	/**
	 * 
	 * @param success
	 * @param code
	 * @param msg
	 * @param data
	 */
	public Result(String code, String msg, T data) {
		super();
		this.code = code;
		this.msg = msg;
		this.data = data;
	}

	/**
	 * 
	 * @param success
	 * @param code
	 * @param msg
	 */
	public Result(String code, String msg) {
		super();
		this.code = code;
		this.msg = msg;
	}

	/**
	 * 
	 * @param codeEnum
	 */
	public Result(CodeEnum codeEnum) {
		super();
		this.code = codeEnum.getCode();
		this.msg = codeEnum.getMessage();
	}

	/**
	 * 
	 * @param codeEnum
	 * @param data
	 */
	public Result(CodeEnum codeEnum, T data) {
		super();
		this.code = codeEnum.getCode();
		this.msg = codeEnum.getMessage();
		this.data = data;
	}

	/**
	 * 
	 * @param codeEnum
	 * @param msg
	 * @param data
	 */
	public Result(CodeEnum codeEnum, String msg, T data) {
		super();
		this.code = codeEnum.getCode();
		this.msg = msg;
		this.data = data;
	}

	public static <T> Result<T> info(String code, String msg, T data) {

		return new Result<T>(code, msg, data);
	}
	
	@SuppressWarnings({ "rawtypes", "unchecked" })
	public static <T> Result<T> success() {

		return new Result(CodeEnum.SUCCESS);
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	public static <T> Result<T> success(T data) {

		return new Result(CodeEnum.SUCCESS, data);
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	public static <T> Result<T> success(T data, String msg) {

		return new Result(CodeEnum.SUCCESS.getCode(), msg, data);
	}


	@SuppressWarnings({ "rawtypes", "unchecked" })
	public static <T> Result<T> error(String code, String msg) {

		return new Result(code, msg);
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	public static <T> Result<T> failed(CodeEnum codeEnum) {

		return new Result(codeEnum);
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	public static <T> Result<T> failed(CodeEnum codeEnum, String msg) {

		return new Result(codeEnum.getCode(), msg);
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	public static <T> Result<T> failed(CodeEnum codeEnum, String msg, T data) {

		return new Result(codeEnum.getCode(), msg, data);
	}



	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getMsg() {
		return msg;
	}

	public void setMsg(String msg) {
		this.msg = msg;
	}

	public T getData() {
		return data;
	}

	public void setData(T data) {
		this.data = data;
	}

}
